@@ -4,7 +4,7 @@ from mprop import mproperty
 from subprocess import Popen, PIPE
 import sys
 
-__version__ = "0.103.1"
+__version__ = "0.105.1"
 
 __github_repo = "jupyter-naas/drivers"
 
@@ -415,6 +415,13 @@ def huggingface():
     return Huggingface()
 
 
+@load_driver(extra_requires="twitter")
+def twitter():
+    from naas_drivers.tools.twitter import Twitter
+
+    return Twitter()
+
+
 @load_driver(extra_requires="snowflake")
 def snowflake():
     from naas_drivers.tools.snowflake import Snowflake
