@@ -1,7 +1,7 @@
 import pandas as pd
 import requests
-from urllib.parse import urlencode
 import pydash as _pd
+from urllib.parse import urlencode
 from datetime import datetime
 
 
@@ -641,7 +641,7 @@ class Repositories(Github):
         repository = Github.get_repository_url(url)
 
         df = pd.DataFrame()
-        page = 1
+        page, idx = 1, 0
         while True:
             params = {
                 "per_page": "100",
@@ -657,7 +657,7 @@ class Repositories(Github):
             if len(res_json) == 0:
                 break
 
-            for idx, issue in enumerate(res_json):
+            for issue in res_json:
                 df.loc[idx, "link_to_the_issue"], df.loc[idx, "issue_number"] = (
                     issue["html_url"],
                     issue["number"],
@@ -717,6 +717,9 @@ class Repositories(Github):
                 except Exception:
                     df.loc[idx, "linked_pr_state"] = "None"
                     df.loc[idx, "PR_activity"] = "None"
+
+                idx += 1
+
             page += 1
 
         df["issue_id"] = df.issue_id.astype("int")
